@@ -1,4 +1,4 @@
-from naas_drivers.in_drivers.yahoo_finance import YahooFinance
+from naas_drivers.in_drivers.yahoofinance import YahooFinance
 from naas_drivers.in_drivers.cityfalcon import Cityfalcon
 from naas_drivers.in_drivers.geolocator import Geolocator
 from naas_drivers.in_drivers.newsapi import Newsapi
@@ -24,7 +24,7 @@ from naas_drivers.in_out_drivers.Toucan import Toucan
 import requests
 import os
 
-__version__ = "0.24.8"
+__version__ = "0.24.17"
 
 __github_repo = "jupyter-naas/drivers"
 
